@@ -1,6 +1,6 @@
 package Calendar::Hijri;
 
-$Calendar::Hijri::VERSION = '0.19';
+$Calendar::Hijri::VERSION = '0.20';
 
 =head1 NAME
 
@@ -8,12 +8,11 @@ Calendar::Hijri - Interface to Islamic Calendar.
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
 use Data::Dumper;
-use Term::ANSIColor::Markup;
 use Date::Hijri::Simple;
 
 use Moo;
@@ -129,7 +128,7 @@ Returns current month of the Hijri calendar.
 sub current {
     my ($self) = @_;
 
-    return $self->_calendar($self->date->year, $self->date->month);
+    return $self->date->get_calendar($self->date->month, $self->date->year);
 }
 
 =head2 from_gregorian()
@@ -154,68 +153,13 @@ sub from_julian {
     my ($self, $julian) = @_;
 
     my $date = $self->date->from_julian($julian);
-    return $self->_calendar($date->year, $date->month);
+    return $self->date->get_calendar($date->month, $date->year);
 }
 
 sub as_string {
     my ($self) = @_;
 
-    return $self->_calendar($self->year, $self->month);
-}
-
-#
-#
-# PRIVATE METHODS
-
-sub _calendar {
-    my ($self, $year, $month) = @_;
-
-    $self->date->validate_month($month);
-    $self->date->validate_year($year);
-
-    my $date = Date::Hijri::Simple->new({ year => $year, month => $month, day => 1 });
-    my $start_index = $date->day_of_week;
-    my $days = $self->date->days_in_month_year($month, $year);
-
-    my $line1 = '<blue><bold>+' . ('-')x104 . '+</bold></blue>';
-    my $line2 = '<blue><bold>|</bold></blue>' .
-                (' ')x39 . '<yellow><bold>' .
-                sprintf("%-15s [%4d BE]", $self->date->hijri_months->[$month], $year) .
-                '</bold></yellow>' . (' ')x40 . '<blue><bold>|</bold></blue>';
-    my $line3 = '<blue><bold>+';
-
-    for(1..7) {
-        $line3 .= ('-')x(14) . '+';
-    }
-    $line3 .= '</bold></blue>';
-
-    my $line4 = '<blue><bold>|</bold></blue>' .
-                join("<blue><bold>|</bold></blue>", @{$self->date->hijri_days}) .
-                '<blue><bold>|</bold></blue>';
-
-    my $calendar = join("\n", $line1, $line2, $line3, $line4, $line3)."\n";
-    if ($start_index % 7 != 0) {
-        $calendar .= '<blue><bold>|</bold></blue>              ';
-        map { $calendar .= "               " } (2..($start_index %= 7));
-    }
-    foreach (1 .. $days) {
-        $calendar .= sprintf("<blue><bold>|</bold></blue><cyan><bold>%13d </bold></cyan>", $_);
-        if ($_ != $days) {
-            $calendar .= "<blue><bold>|</bold></blue>\n" . $line3 . "\n"
-                unless (($start_index + $_) % 7);
-        }
-        elsif ($_ == $days) {
-            my $x = 7 - (($start_index + $_) % 7);
-            $calendar .= '<blue><bold>|</bold></blue>              ';
-            if (($x >= 2) && ($x != 7)) {
-                map { $calendar .= ' 'x15 } (1..$x-1);
-            }
-        }
-    }
-
-    $calendar = sprintf("%s<blue><bold>|</bold></blue>\n%s\n", $calendar, $line3);
-
-    return Term::ANSIColor::Markup->colorize($calendar);
+    return $self->date->get_calendar($self->month, $self->year);
 }
 
 =head1 AUTHOR
